#!/bin/sh 
###########################################################################
#
# sybopts.sh -- Helper script for UNIX makefiles that build Open Client
#    and Open Server applications. This script uses the value of
#    the SYBPLATFORM environment variable to determine what platform
#    specific libraries must be linked with the application.
#
# Usage:
#  sybopts.sh <args>
#
#  where <args> can be one or more of the following:
#
#     compile -- Based on SYBPLATFORM, echoes the compiler command
#	and platform-specific compile flags. For example, if
#       SYBPLATFORM indicates a platform with support for 
#	multithreading, the compile flag "-D_REENTRANT" might be 
#	required.
#     comlibs -- Based on SYBPLATFORM, echoes the list of required
#	lower-layer Sybase libraries that must be linked with the
#	application.
#     syslibs -- Based on SYBPLATFORM, echoes the list of required
#	system (i.e., non-Sybase) libraries that must be linked with the
#	application.
#     ct, cs, blk, srv (respectively) -- Based on SYBPLATFORM, echoes 
#	the name of the archive for Client-Library, CS-Library, 
#	Bulk-Library, or Server-Library routines.
#     verify -- Check SYBPLATFORM setting, if ok, echoes the library
#	names that will be used. If not ok, returns non-zero. This
#	argument must appear by itself with no other arguments.
#     verify_threaded -- Returns non-zero if SYBPLATFORM indicates
# 	a version of Client-Library without multi-threaded support.
#     verify_dce -- Returns non-zero if SYBPLATFORM value is not prepended
#       with 'dce_'
#     verify_krb -- Returns non-zero if SYBPLATFORM value is a platform
#       for which we currently do *not* support CyberSAFE Kerberos.  Note
#       that Kerberos is currently only supported on the following UNIX
#       SYBPLATFORMs: sun_svr4, dce_sun_svr4, hp800, and dce_hp800
#
# Example:
# 	COMPILE =       `sh sybopts.sh compile` $(INCLUDE) $(DEFS)
#
###########################################################################

SET_SYBPLATFORM_MSG="Unknown machine type. Please set SYBPLATFORM variable"
BAD_ARGUMENT_MSG="Unknown argument"
THREAD_SUPPORT_MSG="This target requires multi-threaded support."
DCE_SUPPORT_MSG="This target requires that DCE be installed and running."
KRB_SUPPORT_MSG="This target requires that CyberSAFE Kerberos be installed and running."
SYBPLATFORM_MSG="Check the value of your SYBPLATFORM environment variable."

#
# CC: Compiler/Linker name and compile/link flags
GCCFLAGS=" -g -ansi -pedantic -pipe -Wall -Wtraditional -Wpointer-arith -Wstrict-prototypes "
case "${SYBPLATFORM}" in 
	sun4) 		CC="gcc $GCCFLAGS -Bstatic " ;;
	sun_svr4) 	CC="/opt/SUNWspro/bin/cc -g " ;; 
	dce_sun_svr4) 	CC="/opt/SUNWspro/bin/cc -g -D_REENTRANT " ;; 
	linux)		CC="cc -g -D_REENTRANT " ;;
	dce_hp800) 	CC="cc -g -D_THREAD_SAFE -D_REENTRANT -Ae " ;; 
	hpux)		CC="cc -g -Ae +Z +DA1.1 +DS2.0 " ;;
	dce_hpux) 	CC="cc -g -D_POSIX_C_SOURCE=199506L -Ae +Z +DA1.1 +DS2.0 " ;; 
	rs6000) 	CC="xlc -g " ;;
	dce_rs6000) 	CC="xlc_r4 -g -D_THREAD_SAFE " ;;
	axposf)		CC="cc -g" ;;
	dce_axposf)	CC="cc -g -threads" ;;
	sgi|dce_sgi)	CC="cc -g -n32 -mips3 -B static " ;;
	sgi64|dce_sgi64)	CC="cc -g -64 -mips3  -B static " ;;
	*) 		CC="cc -g ";; 
esac ; 

#
# COMLIBS:
# The list of lower-layer Sybase libraries that are required in order 
# to build a Sybase Open Client/Server application, in the order in 
# which they must be linked.
case "${SYBPLATFORM}" in 
	sun4) 
	    COMLIBS=" -ltcl -linsck -lcomn -lintl" ;; 
	axposf|hp800|hpux|rs6000|sun_svr4|sgi)
	    COMLIBS=" -ltcl -lcomn -lintl" ;; 
	linux)
	    COMLIBS=" -lsybtcl -lcomn -lintl" ;; 
	sgi64) 
	    COMLIBS=" -ltcl64 -lcomn64 -lintl64" ;; 
	dce_sun_svr4) 
	    COMLIBS=" -ltcl_r -lcomn_r -lintl_r" ;; 
	dce_axposf|dce_rs6000|dce_hp800|dce_hpux|dce_sgi)
	    COMLIBS=" -ltcl_dce -lcomn_dce -lintl_r" ;; 
	dce_sgi64) 
	    COMLIBS=" -ltcl_dce64 -lcomn_dce64 -lintl_r64" ;; 
	*) 
	    echo " $SET_SYBPLATFORM_MSG "; exit 1;; 
esac

#
# SYSLIBS:
# The list of system libraries that are required in order 
# to build a Sybase Open Client/Server application, in the order in 
# which they must be linked.
case "${SYBPLATFORM}" in 
	sun4) 		SYSLIBS=" -lm" ;; 
	sun_svr4) 	SYSLIBS=" -Bdynamic -lnsl -ldl -lm" ;; 
	dce_sun_svr4) 	SYSLIBS=" -Bdynamic -lnsl -ldl -lthread -lm" ;; 
	linux)		SYSLIBS=" -lnsl -ldl -lm" ;;
	sgi|sgi64)	SYSLIBS=" -B dynamic " ;;
	dce_sgi|dce_sgi64)	SYSLIBS=" -B dynamic -ldce -lm" ;;
	hp800|hpux) 		SYSLIBS=" -Wl -lcl -lm -lBSD -ldld -Wl,-E,+s" ;; 
	dce_hp800) 	SYSLIBS=" -Wl -lcl -lm -lBSD -ldce -lc_r -ldld -Wl,-E,+s" ;; 
	dce_hpux) 	SYSLIBS=" -lpthread -lrt -lcl -lm -lBSD -ldld -Wl,-E,+s " ;; 
	rs6000) 	SYSLIBS=" -lm" ;; 
	dce_rs6000) 	SYSLIBS="-lxdsxom -ldce -lm" ;;
	axposf)		SYSLIBS="-oldstyle_liblookup -lm" ;;
	dce_axposf) 	SYSLIBS="-threads -oldstyle_liblookup " ;;
	*) 		echo " $SET_SYBPLATFORM_MSG "; exit 1;; 
esac

#
# CTLIB, CSLIB, BLKLIB, SRVLIB:
# The names of exposed libraries. These come in multi-threaded
# and single-threaded versions.
case "${SYBPLATFORM}" in
	sgi64)		CTLIB="-lct64"; CSLIB="-lcs64";
	 		BLKLIB="-lblk64"; SRVLIB="-lsrv64"
			;;
	dce_sgi64)	CTLIB="-lct_r64"; CSLIB="-lcs_r64";
	 		BLKLIB="-lblk_r64"; SRVLIB="-lsrv_r64"
			;;
	dce_*) 		CTLIB="-lct_r"; CSLIB="-lcs_r";
	 		BLKLIB="-lblk_r"; SRVLIB="-lsrv_r"
			;;
	*)  		CTLIB="-lct"; CSLIB="-lcs";
	 		BLKLIB="-lblk"; SRVLIB="-lsrv"
			;;
esac

#
# A single argument of "verify" means that we should print 
# the value of SYBPLATFORM, print the choices that will be made 
# for comlibs, syslibs, etc., then exit with a status of 0. If 
# SYBPLATFORM is incorrect, we will not get here.
#
if [ $1 = "verify" ] 
  then
	echo "SYBPLATFORM is $SYBPLATFORM"
	echo "Compiling with $CC"
	echo "Sybase base libraries: $COMLIBS"
	echo "System libraries: $SYSLIBS"
	exit 0
fi

if [ $1 = verify_threaded ]
  then
	case $SYBPLATFORM in
		dce_*) 
			exit 0;;
		*)
			echo " $THREAD_SUPPORT_MSG";
			exit 1 ;;
	esac
	exit 0
fi

#
# Ensure that DCE is installed and running.  (For now, simply verify that the
# user has set SYBPLATFORM to dce_<platform>.)
#
if [ $1 = verify_dce ]
  then
	case $SYBPLATFORM in
		dce_*) 
			exit 0;;
		*)
			echo " $DCE_SUPPORT_MSG";
			echo " $SYBPLATFORM_MSG";
			exit 1 ;;
	esac
	exit 0
fi

#
# Ensure that Kerberos is installed and running.  (Note that Kerberos is
# currently only supported on sun_svr4 (dce and non-dce) and hp800 (dce and
# non-dce))
#
if [ $1 = verify_krb ]
  then
	case ${SYBPLATFORM} in
		*sun_svr4|*hp800|nthread_rs6000|dce_rs6000)
			exit 0;;
		*)
			echo " $KRB_SUPPORT_MSG";
			exit 1 ;;
	esac
	exit 0
fi

#
# Echo any system specific kerberos library required.
if [ $1 = "krblibs" ]
then
	case "${SYBPLATFORM}" in
		nthread_rs6000|dce_rs6000)
			KRBLIBS="" ;
			;;
		*)
			KRBLIBS="" ;
			;;
	esac
	echo $KRBLIBS
	exit 0 ;
fi


#
# Build a string to echo what was asked for:
#
ECHOSTRING=""
for a
do
	case "$a" in 
		compile) 	ECHOSTRING="$ECHOSTRING $CC" ;;
		comlibs) 	ECHOSTRING="$ECHOSTRING $COMLIBS" ;;
		syslibs) 	ECHOSTRING="$ECHOSTRING $SYSLIBS " ;;
		ct) 		ECHOSTRING="$ECHOSTRING $CTLIB" ;;
		cs) 		ECHOSTRING="$ECHOSTRING $CSLIB" ;;
		srv) 		ECHOSTRING="$ECHOSTRING $SRVLIB" ;;
		blk) 		ECHOSTRING="$ECHOSTRING $BLKLIB" ;;
		*) 		echo "$0: $a: $BAD_ARGUMENT_MSG "; exit 1;;
	esac
done

echo "$ECHOSTRING"
exit 0
